# Generated by roxygen2: do not edit by hand

S3method(autoplot,macrofilter)
S3method(print,macrofilter)
export(autoplot)
export(bhp_filter)
export(hamilton_filter)
export(hp_filter)
export(mbh_filter)
importFrom(Matrix,Diagonal)
importFrom(Matrix,bandSparse)
importFrom(Matrix,crossprod)
importFrom(Matrix,solve)
importFrom(data.table,":=")
importFrom(data.table,data.table)
importFrom(data.table,setorder)
importFrom(ggplot2,aes)
importFrom(ggplot2,autoplot)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(mboost,Huber)
importFrom(mboost,bbs)
importFrom(mboost,bols)
importFrom(mboost,boost_control)
importFrom(mboost,mboost)
importFrom(mboost,mstop)
importFrom(stats,AIC)
importFrom(stats,embed)
importFrom(stats,fitted)
importFrom(stats,frequency)
importFrom(stats,lm.fit)
importFrom(stats,mad)
importFrom(stats,qnorm)
importFrom(stats,sd)
importFrom(stats,ts)
importFrom(stats,tsp)
importFrom(tseries,adf.test)
